<?php

namespace Drupal\d8_google_optimize_hide_page\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements Google Optimize Hide Page Admin Settings form.
 */
class GoogleOptimizeHidePageAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_analytics_reports_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'google_optimize_hide_page.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('google_optimize_hide_page.settings');
    $form['enabled'] = [
      '#type' => 'fieldset',
      '#title' => t('Enabled Google Optimize page-hiding snippet'),
    ];

    $form['enabled']['google_optimize_hide_page_enable'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable'),
      '#default_value' => d8_google_optimize_hide_page_enabled(),
      '#description' => t('Enable/disable the Google Optimize page-hiding snippet.'),
    ];

    $form['settings'] = [
      '#type' => 'fieldset',
      '#title' => t('Settings for the Google Optimize page-hiding snippet'),
      '#states' => [
        'visible' => [
          ':input[name="google_optimize_hide_page_enable"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['settings']['google_optimize_hide_page_container_ids'] = [
      '#title' => t('Container Ids (GTM-XXXXXX), separated by commas'),
      '#type' => 'textfield',
      '#default_value' => implode(',', d8_google_optimize_hide_page_container_ids()),
      '#description' => t('A list Optimize container IDs separated by commas'),
      '#maxlength' => 500,
    ];

    $form['settings']['google_optimize_hide_page_timeout'] = [
      '#title' => t('Timeout'),
      '#type' => 'textfield',
      '#default_value' => d8_google_optimize_hide_page_timeout(),
      '#description' => t('The default amount of time Optimize will wait before removing the .async-hide class from the html element'),
    ];

    $form['settings']['google_optimize_hide_page_class_name'] = [
      '#title' => t('Class name'),
      '#type' => 'textfield',
      '#default_value' => d8_google_optimize_hide_page_class_name(),
      '#description' => t('If the async-hide class name is already defined in your CSS, you can choose a different name.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::configFactory()->getEditable('google_optimize_hide_page.settings')
      ->set('google_optimize_hide_page_enable', $form_state->getValue('google_optimize_hide_page_enable'))
      ->set('google_optimize_hide_page_container_ids', $form_state->getValue('google_optimize_hide_page_container_ids'))
      ->set('google_optimize_hide_page_timeout', $form_state->getValue('google_optimize_hide_page_timeout'))
      ->set('google_optimize_hide_page_class_name', $form_state->getValue('google_optimize_hide_page_class_name'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
